Demo page

### Defaults

Click here to see a minimally configured tooltip. By default tooltips are triggered by clicking and they will show the contents of the title attribute of the element being clicked.

### Configurations

Tooltips can be configured. Click the following link to show the same content in the link inside the tooltip.

You can configure tooltips to set their preferred positions as well when they will appear. This tooltipis configured to preferably appear in the top middle, but won't appear there if there isn't enough space.

#### How tooltips are closed

The way tooltips close, can be configured configured in different ways.

- This following tooltip is configured to be sticky. It will only be closed when you click outside of it.
- This tooltip is configured to have a close button which must be clicked to close it.

### Ajax loading

This tooltip's content is loaded by Ajax on hover and this one's loaded by Ajax too, but on click.

### Images

Even images can have tooltips. Click on the image below to show a tooltip.